@@ -19,9 +19,7 @@ import mock
 from oslo_utils import timeutils
 from oslotest import base
 
-from ceilometer.ceilosca_mapping.ceilosca_mapping import (
-    CeiloscaMappingDefinitionException)
-from ceilometer import monasca_ceilometer_opts
+from ceilometer import monasca_opts
 from ceilometer.publisher import monasca_data_filter as mdf
 from ceilometer import sample
 from ceilometer import service
@@ -31,7 +29,7 @@ class TestMonUtils(base.BaseTestCase):
     def setUp(self):
         super(TestMonUtils, self).setUp()
         self.CONF = service.prepare_service([], [])
-        self.CONF.register_opts(list(monasca_ceilometer_opts.OPTS),
+        self.CONF.register_opts(list(monasca_opts.OPTS),
                                 'monasca')
         self._field_mappings = {
             'dimensions': ['resource_id',
@@ -418,7 +416,7 @@ class TestMonUtils(base.BaseTestCase):
             try:
                 # Don't assign to a variable, this should raise
                 data_filter.process_sample_for_monasca(s)
-            except CeiloscaMappingDefinitionException as e:
+            except mdf.CeiloscaMappingDefinitionException as e:
                 self.assertEqual(
                     'Metadata format mismatch, value should be '
                     'a simple string. [\'aaa0001\', \'bbbb002\']',
@@ -503,7 +501,7 @@ class TestMonUtils(base.BaseTestCase):
             try:
                 # Don't assign to a variable as this should raise
                 data_filter.process_sample_for_monasca(s)
-            except CeiloscaMappingDefinitionException as e:
+            except mdf.CeiloscaMappingDefinitionException as e:
                 # Make sure we got the right kind of error
                 # Cannot check the whole message text, as python
                 # may reorder a dict when producing a string version
